'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var endpoint = require('@rest-hooks/endpoint');
var react = require('@rest-hooks/react');
var makeCacheProvider = require('@rest-hooks/react/makeCacheProvider');
var react$1 = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var makeCacheProvider__default = /*#__PURE__*/_interopDefaultLegacy(makeCacheProvider);

const createFetch$1 = react.__INTERNAL__.createFetch;
const createReceive = react.__INTERNAL__.createReceive;
const createReceiveError = react.__INTERNAL__.createReceiveError;
const initialState = react.__INTERNAL__.initialState;
const DELETED = react.__INTERNAL__.DELETED;
const inferResults = react.__INTERNAL__.inferResults;
const createReducer = react.__INTERNAL__.createReducer;
const applyManager = react.__INTERNAL__.applyManager;
const useCacheState$1 = react.__INTERNAL__.useCacheState;

var internal = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createFetch: createFetch$1,
  createReceive: createReceive,
  createReceiveError: createReceiveError,
  initialState: initialState,
  DELETED: DELETED,
  inferResults: inferResults,
  createReducer: createReducer,
  applyManager: applyManager,
  useCacheState: useCacheState$1,
  StateContext: react.StateContext,
  DispatchContext: react.DispatchContext
});

const SIDEEFFECT_TYPES = ['mutate', 'delete'];
function shapeToEndpoint(shape) {
  // make this identity function for endpoints
  if (shape.key) return shape;
  const sideEffect = SIDEEFFECT_TYPES.includes(shape.type);
  const options = {
    ...shape.options,
    key: shape.getFetchKey,
    schema: shape.schema,
    ...(sideEffect && {
      sideEffect
    })
  };
  if (Object.hasOwn(shape, 'fetch')) {
    // simplest form of endpoint without relying on the package
    const endpoint = (...args) => shape.fetch(...args);
    Object.assign(endpoint, options);
    return endpoint;
  }
  return options;
}

/**
 * @deprecated use https://resthooks.io/docs/api/Controller#getResponse directly instead
 *
 * Selects the denormalized form from `state` cache.
 *
 * If `result` is not found, will attempt to generate it naturally
 * using params and schema. This increases cache hit rate for many
 * detail shapes.
 *
 * @returns {denormalizedValue, expiryStatus, expiresAt}
 */
function useDenormalized(shape, params, state, /** @deprecated */
denormalizeCache) {
  const controller = react.useController();
  const endpoint = react$1.useMemo(() => {
    return shapeToEndpoint(shape);
    // we currently don't support shape changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const key = params !== null ? endpoint.key(params) : '';
  const cacheResults = params && state.results[key];

  // Compute denormalized value
  return react$1.useMemo(() => {
    return controller.getResponse(endpoint, params, state);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [cacheResults, state.indexes, state.entities, state.entityMeta, key, cacheResults]);
}

/* eslint-disable @typescript-eslint/ban-types */
/**
 * Access a response if it is available.
 *
 * `useCache` guarantees referential equality globally.
 * @see https://resthooks.io/docs/api/useCache
 */
function useCache(endpoint, ...args) {
  const adaptedEndpoint = react$1.useMemo(() => {
    return shapeToEndpoint(endpoint);
    // we currently don't support shape changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return react.useCache(adaptedEndpoint, ...args);
}

/**
 * Get any errors for a given request
 * @see https://resthooks.io/docs/api/useError
 */
function useError(endpoint, ...args) {
  const adaptedEndpoint = react$1.useMemo(() => {
    return shapeToEndpoint(endpoint);
    // we currently don't support shape changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return react.useError(adaptedEndpoint, ...args);
}

const {
  useCacheState
} = react.__INTERNAL__;

/**
 * Gets meta for a fetch key.
 * @see https://resthooks.io/docs/api/useMeta
 */
function useMeta(endpoint, ...args) {
  const state = useCacheState();
  const key = args[0] ? endpoint.key ? endpoint.key(...args) : endpoint.getFetchKey(args[0]) : '';
  return react$1.useMemo(() => {
    if (!key) return null;
    return selectMeta(state, key);
  }, [key, state]);
}
function selectMeta(state, fetchKey) {
  return state.meta[fetchKey];
}

/** Returns whether the data at this url is fresh or stale
 * @deprecated use https://resthooks.io/docs/api/Controller#getResponse
 */
function useExpiresAt(fetchShape, params, entitiesExpireAt = 0) {
  const meta = useMeta(fetchShape, params);
  if (!meta) {
    return entitiesExpireAt;
  }
  return meta.expiresAt;
}

const {
  createFetch
} = react.__INTERNAL__;

/** Build an imperative dispatcher to issue network requests.
 * @deprecated use https://resthooks.io/docs/api/Controller#fetch
 */
function useFetchDispatcher(throttle = false) {
  const {
    dispatch
  } = react.useController();
  const fetchDispatcher = react$1.useCallback((fetchShape, params, body) => {
    const action = createFetch(fetchShape, {
      params,
      body,
      throttle
    });
    dispatch(action);
    return action.meta.promise;
  }, [dispatch, throttle]);
  // any is due to the ternary that we don't want to deal with in our implementation
  return fetchDispatcher;
}

/**
 * Request a resource if it is not in cache.\
 * @deprecated use https://resthooks.io/docs/api/useFetch
 */
function useRetrieve(fetchShape, params, triggerFetch = false, entitiesExpireAt = 0) {
  const dispatchFetch = useFetchDispatcher(true);
  const expiresAt = useExpiresAt(fetchShape, params, entitiesExpireAt);
  const {
    lastReset
  } = react$1.useContext(react.StateContext);
  return react$1.useMemo(() => {
    // null params mean don't do anything
    if (Date.now() <= expiresAt && !triggerFetch || !params) return;
    return dispatchFetch(fetchShape, params);
    // we need to check against serialized params, since params can change frequently
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [expiresAt, dispatchFetch, params && fetchShape.getFetchKey(params), triggerFetch, lastReset]);
}

/** single form resource */
function useOneResource(fetchShape, params) {
  const state = react$1.useContext(react.StateContext);
  const {
    data,
    expiryStatus,
    expiresAt
  } = useDenormalized(fetchShape, params, state);
  const error = useError(fetchShape, params);
  const maybePromise = useRetrieve(fetchShape, params, expiryStatus === react.ExpiryStatus.Invalid, expiresAt);
  if (expiryStatus !== react.ExpiryStatus.Valid && maybePromise) {
    throw maybePromise;
  }
  if (error) throw error;
  return data;
}

/** many form resource */
function useManyResources(...resourceList) {
  const state = react$1.useContext(react.StateContext);
  const denormalizedValues = resourceList.map(([fetchShape, params]) =>
  // eslint-disable-next-line react-hooks/rules-of-hooks
  useDenormalized(fetchShape, params, state));
  const errorValues = resourceList.map(([fetchShape, params], i) =>
  // eslint-disable-next-line react-hooks/rules-of-hooks
  useError(fetchShape, params));
  const promises = resourceList.map(([fetchShape, params], i) =>
  // eslint-disable-next-line react-hooks/rules-of-hooks
  useRetrieve(fetchShape, params, denormalizedValues[i].expiryStatus === react.ExpiryStatus.Invalid, denormalizedValues[i].expiresAt))
  // only wait on promises without results
  .map((p, i) => denormalizedValues[i].expiryStatus !== react.ExpiryStatus.Valid && p);

  // throw first valid error
  for (let i = 0; i < resourceList.length; i++) {
    const err = errorValues[i];
    // we aren't fetching at all
    // then throw that error
    if (err && !promises[i]) throw err;
  }
  const promise = react$1.useMemo(() => {
    const activePromises = promises.filter(p => p);
    if (activePromises.length) {
      return Promise.all(activePromises);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, promises);
  if (promise) throw promise;
  return denormalizedValues.map(({
    data
  }) => data);
}
function useResource(...args) {
  // this conditional use of hooks is ok as long as the structure of the arguments don't change
  if (Array.isArray(args[0])) {
    // TODO: provide type guard function to detect this
    // eslint-disable-next-line react-hooks/rules-of-hooks
    return useManyResources(...args);
  }
  args = args;
  // TODO: make return types match up with the branching logic we put in here.
  // eslint-disable-next-line react-hooks/rules-of-hooks
  return useOneResource(args[0], args[1]);
}

/**
 * Keeps a resource fresh by subscribing to updates.
 * @see https://resthooks.io/docs/api/useSubscription
 */
function useSubscription(endpoint, ...args) {
  const adaptedEndpoint = react$1.useMemo(() => {
    return shapeToEndpoint(endpoint);
    // we currently don't support shape changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return react.useSubscription(adaptedEndpoint, ...args);
}

Object.hasOwn = Object.hasOwn || /* istanbul ignore next */function hasOwn(it, key) {
  return Object.prototype.hasOwnProperty.call(it, key);
};

Object.defineProperty(exports, 'Endpoint', {
  enumerable: true,
  get: function () { return endpoint.Endpoint; }
});
Object.defineProperty(exports, 'Index', {
  enumerable: true,
  get: function () { return endpoint.Index; }
});
Object.defineProperty(exports, 'makeCacheProvider', {
  enumerable: true,
  get: function () { return makeCacheProvider__default["default"]; }
});
exports.__INTERNAL__ = internal;
exports.useCache = useCache;
exports.useDenormalized = useDenormalized;
exports.useError = useError;
exports.useMeta = useMeta;
exports.useResource = useResource;
exports.useRetrieve = useRetrieve;
exports.useSubscription = useSubscription;
Object.keys(react).forEach(function (k) {
  if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return react[k]; }
  });
});
