import type { ResolveType, Denormalize, DenormalizeNullable } from '@rest-hooks/react';
import { ReadShape, ParamsFromShape } from '../endpoint/index.js';
type ResourceReturn<P, S extends {
    fetch: any;
    schema: any;
}> = CondNull<P, S['schema'] extends undefined ? ResolveType<S['fetch']> | undefined : DenormalizeNullable<S['schema']>, S['schema'] extends undefined ? ResolveType<S['fetch']> : Denormalize<S['schema']>>;
type CondNull<P, A, B> = P extends null ? A : B;
/**
 * Ensure a resource is available.
 * Suspends until it is.
 *
 * `useResource` guarantees referential equality globally.
 * @deprecated use https://resthooks.io/docs/api/useSuspense
 * @throws {Promise} If data is not yet available.
 * @throws {NetworkError} If fetch fails.
 */
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null>(v1: readonly [S1, P1]): [ResourceReturn<P1, S1>];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2]): [ResourceReturn<P1, S1>, ResourceReturn<P2, S2>];
export default function useResource<S extends ReadShape<any, any>, P extends ParamsFromShape<S> | null>(fetchShape: S, params: P): ResourceReturn<P, S>;
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3]): [ResourceReturn<P1, S1>, ResourceReturn<P2, S2>, ResourceReturn<P3, S3>];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null, S12 extends ReadShape<any, any>, P12 extends ParamsFromShape<S12> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11], v12: readonly [S12, P12]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>,
    ResourceReturn<P12, S12>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null, S12 extends ReadShape<any, any>, P12 extends ParamsFromShape<S12> | null, S13 extends ReadShape<any, any>, P13 extends ParamsFromShape<S13> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11], v12: readonly [S12, P12], v13: readonly [S13, P13]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>,
    ResourceReturn<P12, S12>,
    ResourceReturn<P13, S13>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null, S12 extends ReadShape<any, any>, P12 extends ParamsFromShape<S12> | null, S13 extends ReadShape<any, any>, P13 extends ParamsFromShape<S13> | null, S14 extends ReadShape<any, any>, P14 extends ParamsFromShape<S14> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11], v12: readonly [S12, P12], v13: readonly [S13, P13], v14: readonly [S14, P14]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>,
    ResourceReturn<P12, S12>,
    ResourceReturn<P13, S13>,
    ResourceReturn<P14, S14>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null, S12 extends ReadShape<any, any>, P12 extends ParamsFromShape<S12> | null, S13 extends ReadShape<any, any>, P13 extends ParamsFromShape<S13> | null, S14 extends ReadShape<any, any>, P14 extends ParamsFromShape<S14> | null, S15 extends ReadShape<any, any>, P15 extends ParamsFromShape<S15> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11], v12: readonly [S12, P12], v13: readonly [S13, P13], v14: readonly [S14, P14], v15: readonly [S15, P15]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>,
    ResourceReturn<P12, S12>,
    ResourceReturn<P13, S13>,
    ResourceReturn<P14, S14>,
    ResourceReturn<P15, S15>
];
export default function useResource<S1 extends ReadShape<any, any>, P1 extends ParamsFromShape<S1> | null, S2 extends ReadShape<any, any>, P2 extends ParamsFromShape<S2> | null, S3 extends ReadShape<any, any>, P3 extends ParamsFromShape<S3> | null, S4 extends ReadShape<any, any>, P4 extends ParamsFromShape<S4> | null, S5 extends ReadShape<any, any>, P5 extends ParamsFromShape<S5> | null, S6 extends ReadShape<any, any>, P6 extends ParamsFromShape<S6> | null, S7 extends ReadShape<any, any>, P7 extends ParamsFromShape<S7> | null, S8 extends ReadShape<any, any>, P8 extends ParamsFromShape<S8> | null, S9 extends ReadShape<any, any>, P9 extends ParamsFromShape<S9> | null, S10 extends ReadShape<any, any>, P10 extends ParamsFromShape<S10> | null, S11 extends ReadShape<any, any>, P11 extends ParamsFromShape<S11> | null, S12 extends ReadShape<any, any>, P12 extends ParamsFromShape<S12> | null, S13 extends ReadShape<any, any>, P13 extends ParamsFromShape<S13> | null, S14 extends ReadShape<any, any>, P14 extends ParamsFromShape<S14> | null, S15 extends ReadShape<any, any>, P15 extends ParamsFromShape<S15> | null, S16 extends ReadShape<any, any>, P16 extends ParamsFromShape<S16> | null>(v1: readonly [S1, P1], v2: readonly [S2, P2], v3: readonly [S3, P3], v4: readonly [S4, P4], v5: readonly [S5, P5], v6: readonly [S6, P6], v7: readonly [S7, P7], v8: readonly [S8, P8], v9: readonly [S9, P9], v10: readonly [S10, P10], v11: readonly [S11, P11], v12: readonly [S12, P12], v13: readonly [S13, P13], v14: readonly [S14, P14], v15: readonly [S15, P15], v16: readonly [S16, P16]): [
    ResourceReturn<P1, S1>,
    ResourceReturn<P2, S2>,
    ResourceReturn<P3, S3>,
    ResourceReturn<P4, S4>,
    ResourceReturn<P5, S5>,
    ResourceReturn<P6, S6>,
    ResourceReturn<P7, S7>,
    ResourceReturn<P8, S8>,
    ResourceReturn<P9, S9>,
    ResourceReturn<P10, S10>,
    ResourceReturn<P11, S11>,
    ResourceReturn<P12, S12>,
    ResourceReturn<P13, S13>,
    ResourceReturn<P14, S14>,
    ResourceReturn<P15, S15>,
    ResourceReturn<P16, S16>
];
export {};
//# sourceMappingURL=useResource.d.ts.map